==> zego_zpns-0.1.0.tar.gz: ios/Classes/ZegoZpnsPlugin.m <==
#import "ZegoZpnsPlugin.h"
#import <ZPNs/ZPNs.h>

@interface ZegoZpnsPlugin ()<ZPNsNotificationCenterDelegate>

@property (nonatomic, strong) FlutterEventChannel *eventChannel;

@property (nonatomic, strong) FlutterEventSink events;

@property bool debug;

@end

@implementation ZegoZpnsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"zego_zpns"
            binaryMessenger:[registrar messenger]];
  ZegoZpnsPlugin* instance = [[ZegoZpnsPlugin alloc] init];
  [registrar addApplicationDelegate:instance];
  [registrar addMethodCallDelegate:instance channel:channel];
  [[ZPNs shared] setZPNsNotificationCenterDelegate:(id)self];
  FlutterEventChannel *eventChannel = [FlutterEventChannel eventChannelWithName:@"zpns_event_handler" binaryMessenger:[registrar messenger]];
  [eventChannel setStreamHandler:(id)instance];
  instance.eventChannel = eventChannel;
}

- (FlutterError* _Nullable)onListenWithArguments:(id _Nullable)arguments
                                       eventSink:(FlutterEventSink)events {
    self.events = events;
    
    return nil;
}

- (FlutterError* _Nullable)onCancelWithArguments:(id _Nullable)arguments {
    self.events = nil;
    return nil;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else if ([@"getVersion" isEqualToString:call.method]){
      
      result([ZPNs getVersion]);
  }
  else if ([@"applyNotificationPermission" isEqualToString:call.method]){
      
          if (@available(iOS 10.0, *)) {
              UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
              center.delegate = self;
              [center requestAuthorizationWithOptions:(UNAuthorizationOptionAlert | UNAuthorizationOptionBadge | UNAuthorizationOptionSound) completionHandler:^(BOOL granted, NSError * _Nullable error) {
                  if (granted) {
                      //点击允许
                      [center getNotificationSettingsWithCompletionHandler:^(UNNotificationSettings * _Nonnull settings) {

                      }];

                  } else {

                  }
              }];
              center.delegate = self;
          }
          else if ([[UIDevice currentDevice].systemVersion floatValue] >8.0){
              //iOS8 - iOS10
              [[UIApplication sharedApplication] registerUserNotificationSettings:[UIUserNotificationSettings settingsForTypes:UIUserNotificationTypeAlert | UIUserNotificationTypeSound | UIUserNotificationTypeBadge categories:nil]];
          }
          else {
              // Fallback on earlier versions
          }
  }
  else if ([@"enableDebug" isEqualToString:call.method]){
      self.debug = [[call.arguments objectForKey:@"debug"] boolValue];
      result(nil);
  }
  else if ([@"getPushConfig" isEqualToString:call.method]){
      result([FlutterError errorWithCode:@"1" message:@"This interface is only available for Android" details:nil]);
  }
  else if ([@"setPushConfig" isEqualToString:call.method]){
      result([FlutterError errorWithCode:@"1" message:@"This interface is only available for Android" details:nil]);
  }
  else if ([@"registerPush" isEqualToString:call.method]){
      [[ZPNs shared] registerAPNs];
      result(nil);
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

#pragma mark - ZPNsNotificationCenterDelegate

- (void)onRegistered:(NSString *)Pushid{
    if(_events == nil){
        return;
    }
    NSDictionary *resultDic = @{@"method":@"onRegistered",@"message":@{@"pushID":Pushid,@"errorCode":[NSNumber numberWithInt:0]}};
    _events(resultDic);
}



- (void)ZPNsNotificationCenter:(UNUserNotificationCenter *)center
       willPresentNotification:(UNNotification *)notification
                      userInfo:(NSDictionary *)userInfo
         withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler
API_AVAILABLE(macos(10.14), ios(10.0)){
    if(_events == nil){
        return;
    }
    NSMutableDictionary *messageMap = [[NSMutableDictionary alloc] init];
    NSDictionary *apsMap = [userInfo objectForKey:@"aps"];
    NSDictionary *alertMap = [apsMap objectForKey:@"alert"];
    
    [messageMap setObject:[alertMap objectForKey:@"title"] forKey:@"title"];
    [messageMap setObject:[alertMap objectForKey:@"body"] forKey:@"content"];
    [messageMap setObject:[userInfo objectForKey:@"payload"] forKey:@"extendData"];
    
    NSDictionary *resultDic = @{@"method":@"onNotificationArrived",@"message":messageMap};
    _events(resultDic);
}

- (void)ZPNsNotificationCenter:(UNUserNotificationCenter *)center
    didReceiveNotificationResponse:(UNNotificationResponse *)response
                          userInfo:(NSDictionary *)userInfo
         withCompletionHandler:(void (^)(void))completionHandler API_AVAILABLE(macos(10.14), ios(10.0)){
    if(_events == nil){
        return;
    }
    NSMutableDictionary *messageMap = [[NSMutableDictionary alloc] init];
    NSDictionary *apsMap = [userInfo objectForKey:@"aps"];
    NSDictionary *alertMap = [apsMap objectForKey:@"alert"];
    
    [messageMap setObject:[alertMap objectForKey:@"title"] forKey:@"title"];
    [messageMap setObject:[alertMap objectForKey:@"body"] forKey:@"content"];
    [messageMap setObject:[userInfo objectForKey:@"payload"] forKey:@"extendData"];
    
    NSDictionary *resultDic = @{@"method":@"onNotificationClicked",@"userInfo":messageMap};
    _events(resultDic);
}
#pragma mark - AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    
    return YES;
}

- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
    [[ZPNs shared] setDeviceToken:deviceToken isProduct:!self.debug];
}

- (void)application:(UIApplication*)application
didFailToRegisterForRemoteNotificationsWithError:(NSError*)error{
    NSDictionary *resultDic = @{@"method":@"onRegistered",@"message":@{@"pushID":@"",@"errorCode":[NSNumber numberWithInt:1]}};
    _events(resultDic);
}


@end

==> zego_zpns-0.1.1.tar.gz: ios/Classes/ZegoZpnsPlugin.m <==
#import "ZegoZpnsPlugin.h"
#import <ZPNs/ZPNs.h>

@interface ZegoZpnsPlugin ()<ZPNsNotificationCenterDelegate>

@property (nonatomic, strong) FlutterEventChannel *eventChannel;

@property (nonatomic, strong) FlutterEventSink events;

@property bool debug;

@end

@implementation ZegoZpnsPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"zego_zpns"
            binaryMessenger:[registrar messenger]];
  ZegoZpnsPlugin* instance = [[ZegoZpnsPlugin alloc] init];
  [registrar addApplicationDelegate:instance];
  [registrar addMethodCallDelegate:instance channel:channel];
  [[ZPNs shared] setZPNsNotificationCenterDelegate:(id)instance];
  FlutterEventChannel *eventChannel = [FlutterEventChannel eventChannelWithName:@"zpns_event_handler" binaryMessenger:[registrar messenger]];
  [eventChannel setStreamHandler:(id)instance];
  instance.eventChannel = eventChannel;
}

- (FlutterError* _Nullable)onListenWithArguments:(id _Nullable)arguments
                                       eventSink:(FlutterEventSink)events {
    self.events = events;
    
    return nil;
}

- (FlutterError* _Nullable)onCancelWithArguments:(id _Nullable)arguments {
    self.events = nil;
    return nil;
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  }
  else if ([@"getVersion" isEqualToString:call.method]){
      
      result([ZPNs getVersion]);
  }
  else if ([@"applyNotificationPermission" isEqualToString:call.method]){
      
          if (@available(iOS 10.0, *)) {
              UNUserNotificationCenter *center = [UNUserNotificationCenter currentNotificationCenter];
              center.delegate = self;
              [center requestAuthorizationWithOptions:(UNAuthorizationOptionAlert | UNAuthorizationOptionBadge | UNAuthorizationOptionSound) completionHandler:^(BOOL granted, NSError * _Nullable error) {
                  if (granted) {
                      //点击允许
                      [center getNotificationSettingsWithCompletionHandler:^(UNNotificationSettings * _Nonnull settings) {

                      }];

                  } else {

                  }
              }];
              center.delegate = self;
          }
          else if ([[UIDevice currentDevice].systemVersion floatValue] >8.0){
              //iOS8 - iOS10
              [[UIApplication sharedApplication] registerUserNotificationSettings:[UIUserNotificationSettings settingsForTypes:UIUserNotificationTypeAlert | UIUserNotificationTypeSound | UIUserNotificationTypeBadge categories:nil]];
          }
          else {
              // Fallback on earlier versions
          }
  }
  else if ([@"enableDebug" isEqualToString:call.method]){
      self.debug = [[call.arguments objectForKey:@"debug"] boolValue];
      result(nil);
  }
  else if ([@"getPushConfig" isEqualToString:call.method]){
      result([FlutterError errorWithCode:@"1" message:@"This interface is only available for Android" details:nil]);
  }
  else if ([@"setPushConfig" isEqualToString:call.method]){
      result([FlutterError errorWithCode:@"1" message:@"This interface is only available for Android" details:nil]);
  }
  else if ([@"registerPush" isEqualToString:call.method]){
      [[ZPNs shared] registerAPNs];
      result(nil);
  }
  else {
    result(FlutterMethodNotImplemented);
  }
}

#pragma mark - ZPNsNotificationCenterDelegate

- (void)onRegistered:(NSString *)Pushid{
    if(_events == nil){
        return;
    }
    NSDictionary *resultDic = @{@"method":@"onRegistered",@"message":@{@"pushID":Pushid,@"errorCode":[NSNumber numberWithInt:0]}};
    _events(resultDic);
}



- (void)ZPNsNotificationCenter:(UNUserNotificationCenter *)center
       willPresentNotification:(UNNotification *)notification
                      userInfo:(NSDictionary *)userInfo
         withCompletionHandler:(void (^)(UNNotificationPresentationOptions))completionHandler
API_AVAILABLE(macos(10.14), ios(10.0)){
    if(_events == nil){
        return;
    }
    NSMutableDictionary *messageMap = [[NSMutableDictionary alloc] init];
    NSDictionary *apsMap = [userInfo objectForKey:@"aps"];
    NSDictionary *alertMap = [apsMap objectForKey:@"alert"];
    
    [messageMap setObject:[alertMap objectForKey:@"title"] forKey:@"title"];
    [messageMap setObject:[alertMap objectForKey:@"body"] forKey:@"content"];
    [messageMap setObject:[userInfo objectForKey:@"payload"] forKey:@"extendData"];
    
    NSDictionary *resultDic = @{@"method":@"onNotificationArrived",@"message":messageMap};
    _events(resultDic);
}

- (void)ZPNsNotificationCenter:(UNUserNotificationCenter *)center
    didReceiveNotificationResponse:(UNNotificationResponse *)response
                          userInfo:(NSDictionary *)userInfo
         withCompletionHandler:(void (^)(void))completionHandler API_AVAILABLE(macos(10.14), ios(10.0)){
    if(_events == nil){
        return;
    }
    NSMutableDictionary *messageMap = [[NSMutableDictionary alloc] init];
    NSDictionary *apsMap = [userInfo objectForKey:@"aps"];
    NSDictionary *alertMap = [apsMap objectForKey:@"alert"];
    
    [messageMap setObject:[alertMap objectForKey:@"title"] forKey:@"title"];
    [messageMap setObject:[alertMap objectForKey:@"body"] forKey:@"content"];
    [messageMap setObject:[userInfo objectForKey:@"payload"] forKey:@"extendData"];
    
    NSDictionary *resultDic = @{@"method":@"onNotificationClicked",@"userInfo":messageMap};
    _events(resultDic);
}
#pragma mark - AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    
    return YES;
}

- (void)application:(UIApplication *)application didRegisterForRemoteNotificationsWithDeviceToken:(NSData *)deviceToken {
    [[ZPNs shared] setDeviceToken:deviceToken isProduct:!self.debug];
}

- (void)application:(UIApplication*)application
didFailToRegisterForRemoteNotificationsWithError:(NSError*)error{
    NSDictionary *resultDic = @{@"method":@"onRegistered",@"message":@{@"pushID":@"",@"errorCode":[NSNumber numberWithInt:1]}};
    _events(resultDic);
}


@end
